@@ -28,6 +28,7 @@ from pm4py.objects.log.obj import EventLog, EventStream
 import pandas as pd
 from pm4py.objects.petri_net.obj import PetriNet, Marking
 from pm4py.util import typing
+import warnings
 
 
 class Parameters(Enum):
@@ -291,6 +292,8 @@ def apply(log: EventLog, net: PetriNet, initial_marking: Marking, final_marking:
     if parameters is None:
         parameters = {}
 
+    warnings.warn("the backwards variant of TBR will be removed in a future version.")
+
     for t in net.transitions:
         ma = Marking()
         for a in t.out_arcs:
