@@ -14,4 +14,5 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.algo.transformation.ocel.features.objects import algorithm, object_cobirth_graph, object_codeath_graph, object_degree_centrality, object_general_descendants_graph, object_general_inheritance_graph, object_general_interaction_graph, object_lifecycle_activities, object_lifecycle_duration, object_lifecycle_length, object_str_attributes, object_num_attributes, objects_interaction_graph_ot, object_work_in_progress, related_events_features, related_activities_features, obj_con_in_graph_features
+
+from pm4py.algo.transformation.ocel.features.objects import algorithm, object_cobirth_graph, object_codeath_graph, object_degree_centrality, object_general_descendants_graph, object_general_inheritance_graph, object_general_interaction_graph, object_lifecycle_activities, object_lifecycle_duration, object_lifecycle_length, object_str_attributes, object_num_attributes, objects_interaction_graph_ot, object_work_in_progress, related_events_features, related_activities_features, obj_con_in_graph_features, object_lifecycle_unq_act
