@@ -15,3 +15,7 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from pm4py.statistics.overlap import cases, utils
+
+import warnings
+
+warnings.warn("The overlap package will be removed in a future release.")
