@@ -14,13 +14,16 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.util.xes_constants import DEFAULT_NAME_KEY, DEFAULT_TIMESTAMP_KEY
-from pm4py.util import exec_utils, variants_util, constants
+from enum import Enum
+from typing import Optional, Dict, Any, Union, Tuple, List
 
 import numpy as np
 
+from pm4py.objects.log.obj import EventLog, Trace
 from pm4py.util import constants
-from enum import Enum
+from pm4py.util import exec_utils, variants_util
+from pm4py.util.xes_constants import DEFAULT_TIMESTAMP_KEY
+from pm4py.objects.conversion.log import converter as log_converter
 
 
 class Parameters(Enum):
@@ -33,7 +36,8 @@ class Parameters(Enum):
     KEEP_ONCE_PER_CASE = "keep_once_per_case"
 
 
-def get_language(log, parameters=None):
+def get_language(log: EventLog, parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> Union[
+    Dict[List[str], float], Dict[str, float]]:
     """
     Gets the stochastic language of the log (from the variants)
 
@@ -50,6 +54,7 @@ def get_language(log, parameters=None):
         Dictionary containing the stochastic language of the log
         (variant associated to a number between 0 and 1; the sum is 1)
     """
+    log = log_converter.apply(log, variant=log_converter.Variants.TO_EVENT_LOG, parameters=parameters)
     vars = get_variants(log, parameters=parameters)
     vars = {variants_util.get_activities_from_variant(x): len(y) for x, y in vars.items()}
 
@@ -59,7 +64,8 @@ def get_language(log, parameters=None):
     return vars
 
 
-def get_variants(log, parameters=None):
+def get_variants(log: EventLog, parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> Union[
+    Dict[List[str], List[Trace]], Dict[str, List[Trace]]]:
     """
     Gets a dictionary whose key is the variant and as value there
     is the list of traces that share the variant
@@ -77,6 +83,7 @@ def get_variants(log, parameters=None):
     variant
         Dictionary with variant as the key and the list of traces as the value
     """
+    log = log_converter.apply(log, variant=log_converter.Variants.TO_EVENT_LOG, parameters=parameters)
 
     variants_trace_idx = get_variants_from_log_trace_idx(log, parameters=parameters)
 
@@ -85,7 +92,9 @@ def get_variants(log, parameters=None):
     return all_var
 
 
-def get_variants_along_with_case_durations(log, parameters=None):
+def get_variants_along_with_case_durations(log: EventLog,
+                                           parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> Tuple[
+    Union[Dict[List[str], List[Trace]], Dict[str, List[Trace]]], np.array]:
     """
     Gets a dictionary whose key is the variant and as value there
     is the list of traces that share the variant
@@ -106,6 +115,8 @@ def get_variants_along_with_case_durations(log, parameters=None):
     if parameters is None:
         parameters = {}
 
+    log = log_converter.apply(log, variant=log_converter.Variants.TO_EVENT_LOG, parameters=parameters)
+
     timestamp_key = exec_utils.get_param_value(Parameters.TIMESTAMP_KEY, parameters, DEFAULT_TIMESTAMP_KEY)
 
     variants_trace_idx = get_variants_from_log_trace_idx(log, parameters=parameters)
@@ -146,6 +157,8 @@ def get_variants_from_log_trace_idx(log, parameters=None):
     if parameters is None:
         parameters = {}
 
+    log = log_converter.apply(log, variant=log_converter.Variants.TO_EVENT_LOG, parameters=parameters)
+
     variants = {}
     for trace_idx, trace in enumerate(log):
         variant = variants_util.get_variant_from_trace(trace, parameters=parameters)
@@ -194,6 +207,8 @@ def convert_variants_trace_idx_to_trace_obj(log, variants_trace_idx):
     variants
         Variants associated to a list of belonging traces
     """
+    log = log_converter.apply(log, variant=log_converter.Variants.TO_EVENT_LOG)
+
     variants = {}
 
     for key in variants_trace_idx:
