@@ -18,7 +18,7 @@ import re
 
 import warnings
 
-warnings.warn("The regex package will be removed in a future release.")
+#warnings.warn("The regex package will be removed in a future release.")
 
 
 def get_new_char(label, shared_obj):
