@@ -18,7 +18,7 @@ import matplotlib
 from copy import copy
 
 from pm4py.visualization.graphs.util import common
-from pm4py.util import exec_utils
+from pm4py.util import exec_utils, constants
 from enum import Enum
 from typing import Optional, Dict, Any, Union, Tuple, List
 
@@ -28,6 +28,8 @@ class Parameters(Enum):
     FORMAT = "format"
     X_AXIS = "x_axis"
     Y_AXIS = "y_axis"
+    PYPLOT_PLOT_KWARGS = "pylot_plot_kwargs"
+    TRANSPARENT = "transparent"
 
 
 CASE_DURATION_LABEL = "Case duration"
@@ -62,6 +64,8 @@ def apply_plot(x: List[float], y: List[float], parameters: Optional[Dict[Union[s
     title = exec_utils.get_param_value(Parameters.TITLE, parameters, GRAPH_DEFAULT_TITLE)
     x_axis = exec_utils.get_param_value(Parameters.X_AXIS, parameters, CASE_DURATION_LABEL)
     y_axis = exec_utils.get_param_value(Parameters.Y_AXIS, parameters, DENSITY_LABEL)
+    pyplot_plot_kwargs = exec_utils.get_param_value(Parameters.PYPLOT_PLOT_KWARGS, parameters, {})
+    is_transp = exec_utils.get_param_value(Parameters.TRANSPARENT, parameters, True if constants.DEFAULT_BGCOLOR == "transparent" else False)
 
     filename = common.get_temp_file_name(format)
 
@@ -70,11 +74,11 @@ def apply_plot(x: List[float], y: List[float], parameters: Optional[Dict[Union[s
     from matplotlib import pyplot
 
     pyplot.clf()
-    pyplot.plot(x, y)
+    pyplot.plot(x, y, **pyplot_plot_kwargs)
     pyplot.xlabel(x_axis)
     pyplot.ylabel(y_axis)
     pyplot.title(title)
-    pyplot.savefig(filename, bbox_inches="tight", transparent=True)
+    pyplot.savefig(filename, bbox_inches="tight", transparent=is_transp)
     pyplot.clf()
 
     matplotlib.use(current_backend)
@@ -107,6 +111,8 @@ def apply_semilogx(x: List[float], y: List[float], parameters: Optional[Dict[Uni
 
     format = exec_utils.get_param_value(Parameters.FORMAT, parameters, "png")
     title = exec_utils.get_param_value(Parameters.TITLE, parameters, GRAPH_DEFAULT_TITLE)
+    pyplot_plot_kwargs = exec_utils.get_param_value(Parameters.PYPLOT_PLOT_KWARGS, parameters, {})
+    is_transp = exec_utils.get_param_value(Parameters.TRANSPARENT, parameters, True if constants.DEFAULT_BGCOLOR == "transparent" else False)
 
     filename = common.get_temp_file_name(format)
 
@@ -115,11 +121,11 @@ def apply_semilogx(x: List[float], y: List[float], parameters: Optional[Dict[Uni
     from matplotlib import pyplot
 
     pyplot.clf()
-    pyplot.semilogx(x, y)
+    pyplot.semilogx(x, y, **pyplot_plot_kwargs)
     pyplot.xlabel(CASE_DURATION_LABEL)
     pyplot.ylabel(DENSITY_LABEL)
     pyplot.title(title)
-    pyplot.savefig(filename, bbox_inches="tight", transparent=True)
+    pyplot.savefig(filename, bbox_inches="tight", transparent=is_transp)
     pyplot.clf()
 
     matplotlib.use(current_backend)
